@@ -4,6 +4,7 @@ The pngme.api package exposes utilities to interact with Pngme's financial data.
 
 
 from .client import AsyncClient, Client
+from .core import AccessTokenExpired, AccessTokenInvalid
 from .resources.alerts import Alert
 from .resources.balances import BalanceRecord
 from .resources.credit_report import CreditReport
@@ -13,6 +14,8 @@ from .resources.transactions import TransactionRecord
 __all__ = (
     "AsyncClient",
     "Client",
+    "AccessTokenExpired",
+    "AccessTokenInvalid",
     "Alert",
     "BalanceRecord",
     "CreditReport",
