@@ -2,7 +2,7 @@ import asyncio
 from datetime import datetime
 from typing import List, Optional, Sequence, Set
 
-from pydantic import BaseModel
+from pydantic import BaseModel, validate_arguments
 
 from ..core import BaseClient
 from ..encoders import encode_query_params
@@ -74,6 +74,7 @@ class BaseTransactionsResource:
         assert response.status_code == 200, response.text
         return TransactionsResponse(**response.json())
 
+    @validate_arguments
     async def _get(
         self,
         user_uuid: str,
